
****************************************************************************
*						 ODS ExcelXP Tagset 						       *
****************************************************************************

*Tagsets are templates and defined using the template procedure;
*lists all possible sas tagsets;
PROC TEMPLATE;  
   LIST tagsets; 
QUIT;

****************************************************************************
*							DATASET CREATION 								*
****************************************************************************;

DATA sales;
	INPUT ID $ Department: $13. Wage: 5.2 hours over_hours;
	LABEL 	hours = 'Number of Hours Worked' 
			over_hours = 'Number of Overtime Hours';
	FORMAT wage dollar7.2;
	CARDS;
	1 General_merch  8.15  40 5
	2 Electronics    10.00 30 0
	3 Grocery        8.75  40 7
	4 Pharmacy       15.40 40 7
	5 Bakery_deli    8.15  35 0
	6 Health_beauty  8.25  20 0
	7 Apparel_Home   8.35  16 0
	8 Pet            9.50  27 0
	9 General_merch  8.20  40 1
	10 Electronics   10.10 30 0
	11 Grocery       9.00  40 3
	12 Pharmacy      12.40 38 0
	13 Bakery_deli   8.35  36 0
	14 Health_beauty 8.50  40 4
	15 Apparel_Home  8.95  22 0
	16 Pet           8.15  26 0
	;
RUN;

DATA sales2;
	SET sales;
	Earnings = wage*hours;
	over_time= (wage*1.5)*over_hours;
	total = earnings + over_time;
	FORMAT earnings dollar7.2 over_time dollar7.2 total dollar7.2;
	LABEL earnings = 'Gross Regular Rate Pay' over_time = 'Gross Overtime Rate Pay' total = 'Gross Pay';
RUN;

****************************************************************************
*Listing all of the options available within the ExcelXP tagset in the log *
****************************************************************************;

ODS tagsets.ExcelXP FILE='C:\Users\vrena\Google Drive\ODS ExcelXP\Sales2.xml' 
STYLE=FestivalPrinter
options(doc="help");
ODS tagsets.ExcelXP CLOSE;
/*this doc=help prints everything there is for options for this excelXP tagset in the log*/

****************************************************************************
*				EX 1: Basic Workbook with PROC REPORT					   *
****************************************************************************;
ODS tagsets.ExcelXP PATH='C:\Users\vrena\Google Drive\ODS ExcelXP' FILE='Sales1.xml'
	STYLE=analysis;
PROC REPORT DATA=sales2 NOWD;
	COLUMNS ID department wage hours over_hours earnings over_time total;
	DEFINE earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	DEFINE over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	DEFINE total / STYLE={tagattr="formula:RC[-2]+RC[-1]"};
RUN;
ODS tagsets.ExcelXP CLOSE;
****************************************************************************
*		EX 2: Adding Options and Excel Formulas with PROC PRINT			   *
****************************************************************************;
ODS tagsets.ExcelXP PATH='C:\Users\vrena\Google Drive\ODS ExcelXP' FILE='Sales2.xml' 
STYLE=FestivalPrinter options(Embedded_Titles='no' /*puts titles in worksheet*/ FitToPage='yes' /*fits dataset
to one page*/ Gridlines='no' /*shows excel gridlines when printing*/ Frozen_RowHeaders= 'no' /*If 'Yes' The header 
columns on the left will be frozen when the table data scrolls.  If a number is given, that is the column 
count that will be frozen.*/ Sheet_Name ='Sales Data' /*adds sheet name in excel*/ index='yes' /*If set to yes, 
The first worksheet will contain a table of contents With a single link to each worksheet in the workbook. If both this 
option and the Contents option are set, then the index of worksheets will be the second worksheet and it will be named 
'Worksheets'.*/ Autofit_height='yes' Absolute_Column_Width = '3.5,16,6.5,10,10,10,10,12');
PROC PRINT DATA=sales2 NOOBS LABEL;
	VAR ID department wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP CLOSE;
****************************************************************************
*			EX 3: Advanced Workbook with PROC REPORT					   *
****************************************************************************;
ODS tagsets.ExcelXP PATH='C:\Users\vrena\Google Drive\ODS ExcelXP' FILE='Sales3.xml'
	STYLE=analysis options(FitToPage='yes' Sheet_Name ='Sales Data' 
	Autofit_height='yes' Absolute_Column_Width = '3.5,16,6.5,10,10,10,10,12');

PROC REPORT DATA=sales NOWD;
	COLUMN id department wage hours over_hours earnings over_time total;
	DEFINE wage / DISPLAY;
	DEFINE over_hours / DISPLAY;
	DEFINE hours / DISPLAY;
	DEFINE earnings / COMPUTED FORMAT=dollar7.2 'Gross Regular Rate Earnings' 
						STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	DEFINE over_time / COMPUTED FORMAT=dollar7.2 'Gross Over Time Earnings'
						STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	DEFINE total / COMPUTED FORMAT=dollar7.2 'Gross Pay'
					STYLE={tagattr="formula:=sum(RC[-2],RC[-1])"};
	COMPUTE earnings;
		earnings = wage*hours;
	ENDCOMP;
	COMPUTE over_time;
		over_time = (wage*1.5)*over_hours;
	ENDCOMP;
	COMPUTE total;
		total = earnings + over_time;
	ENDCOMP;
RUN;
ODS tagsets.ExcelXP CLOSE;
****************************************************************************
*				EX 4: Tricking SAS Output for Excel						   *
****************************************************************************;
ODS tagsets.ExcelXP PATH='C:\Users\vrena\Google Drive\ODS ExcelXP' FILE='Sales4.xml'
	STYLE=FestivalPrinter options(FitToPage='yes' Sheet_Name ='Sales Data'
	Autofit_height='yes' Absolute_Column_Width = '3.5,16,6.5,10,10,10,10,12');
PROC PRINT DATA=sales2 LABEL NOOBS;
	VAR id department wage hours over_hours;
	VAR earnings/ STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time /STYLE={tagattr="formula:RC[-4]*RC[-2]*1.5"};
	VAR total / STYLE={tagattr="formula:RC[-2]+RC[-1]"};
	SUM total /STYLE={tagattr="formula:=AVERAGE(R[-16]C[0]:R[-1]C[0])"};
	SUM earnings/STYLE={tagattr="formula:=AVERAGE(R[-16]C[0]:R[-1]C[0])"};
RUN;
ODS tagsets.ExcelXP CLOSE;

****************************************************************************
*				Ex 5. Outputting Multiple Worksheets					   *
****************************************************************************;

DATA gen elect gro phar bake health app pet;
	SET sales2;
	IF department = 'General_merch' THEN OUTPUT gen;
		ELSE IF department = 'Electronics' THEN OUTPUT elect;
		ELSE IF department = 'Grocery' THEN OUTPUT gro;
		ELSE IF department = 'Pharmacy' THEN OUTPUT phar;
		ELSE IF department = 'Bakery_deli' THEN OUTPUT bake;
		ELSE IF department = 'Health_beauty' THEN OUTPUT health;
		ELSE IF department = 'Apparel_Home' THEN OUTPUT app;
		ELSE output pet;
RUN; 

ODS tagsets.ExcelXP PATH='C:\Users\vrena\Google Drive\ODS ExcelXP' FILE='Sales5.xml'
	STYLE=FestivalPrinter options(FitToPage='yes' Sheet_Name ='General_merch'
	Autofit_height='yes' Absolute_Column_Width = '3.5,16,6.5,10,10,10,10,12');
PROC PRINT DATA=gen NOOBS LABEL;
	VAR ID wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP options(Sheet_Name ='Electronics');
PROC PRINT DATA=elect NOOBS LABEL;
	VAR ID wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP options(Sheet_Name ='Grocery');
PROC PRINT DATA=gro NOOBS LABEL;
	VAR ID wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP options(Sheet_Name ='Pharmacy');
PROC PRINT DATA=phar NOOBS LABEL;
	VAR ID wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP options(Sheet_Name ='Bakery_deli');
PROC PRINT DATA=bake NOOBS LABEL;
	VAR ID wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP options(Sheet_Name ='Health_beauty');
PROC PRINT DATA=health NOOBS LABEL;
	VAR ID wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP options(Sheet_Name ='Apparel_home');
PROC PRINT DATA=app NOOBS LABEL;
	VAR ID wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP options(Sheet_Name ='Pet');
PROC PRINT DATA=pet NOOBS LABEL;
	VAR ID wage hours over_hours;
	VAR Earnings / STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	VAR over_time / STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	VAR total / STYLE={tagattr="formula:sum(RC[-2],RC[-1])"};
RUN;
ODS tagsets.ExcelXP CLOSE;

****************************************************************************
*		Ex 6. Outputting Multiple Datasets to the Same Worksheet			*
****************************************************************************;

ODS tagsets.ExcelXP PATH='C:\Users\vrena\Google Drive\ODS ExcelXP' FILE='Sales6.xml'
	STYLE=FestivalPrinter options(FitToPage='yes' Sheet_Name ='General_merch & Electronics' 
	sheet_interval = 'None' Autofit_height='yes' Absolute_Column_Width = '3.5,16,6.5,10,10,10,10,12');

PROC REPORT DATA=gen NOWD;
	COLUMN ID wage hours over_hours earnings over_time total;
	DEFINE ID / DISPLAY;
	DEFINE wage / DISPLAY;
	DEFINE over_hours / DISPLAY;
	DEFINE hours / DISPLAY;
	DEFINE earnings / DISPLAY FORMAT=dollar7.2 'Gross Regular Rate Earnings' 
						STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	DEFINE over_time / DISPLAY FORMAT=dollar7.2 'Gross Over Time Earnings'
						STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	DEFINE total / DISPLAY FORMAT=dollar7.2 'Gross Pay'
					STYLE={tagattr="formula:=sum(RC[-2],RC[-1])"};
	COMPUTE BEFORE _PAGE_ / STYLE=[font_size=3 font_weight=bold bordercolor=black] CENTER; 
			LINE 'General Merchandise';
	ENDCOMP;
RUN;

PROC REPORT DATA=elect NOWD;
	COLUMN ID wage hours over_hours earnings over_time total;
	DEFINE ID / DISPLAY;
	DEFINE wage / DISPLAY;
	DEFINE over_hours / DISPLAY;
	DEFINE hours / DISPLAY;
	DEFINE earnings / DISPLAY FORMAT=dollar7.2 'Gross Regular Rate Earnings' 
						STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	DEFINE over_time / DISPLAY FORMAT=dollar7.2 'Gross Over Time Earnings'
						STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	DEFINE total / DISPLAY FORMAT=dollar7.2 'Gross Pay'
					STYLE={tagattr="formula:=sum(RC[-2],RC[-1])"};
	COMPUTE BEFORE _PAGE_ / STYLE=[font_size=3 font_weight=bold bordercolor=black ] CENTER; 
			LINE 'Electronics';
	ENDCOMP;
RUN;

ODS tagsets.ExcelXP options(Sheet_Name ='Grocery' sheet_interval = 'Table');
PROC REPORT DATA=gro NOWD;
	COLUMN ID wage hours over_hours earnings over_time total;
	DEFINE ID / DISPLAY;
	DEFINE wage / DISPLAY;
	DEFINE over_hours / DISPLAY;
	DEFINE hours / DISPLAY;
	DEFINE earnings / DISPLAY FORMAT=dollar7.2 'Gross Regular Rate Earnings' 
						STYLE={tagattr="formula:RC[-3]*RC[-2]"};
	DEFINE over_time / DISPLAY FORMAT=dollar7.2 'Gross Over Time Earnings'
						STYLE={tagattr="formula:RC[-4]*1.5*RC[-2]"};
	DEFINE total / DISPLAY FORMAT=dollar7.2 'Gross Pay'
					STYLE={tagattr="formula:=sum(RC[-2],RC[-1])"};
	COMPUTE BEFORE _PAGE_ / STYLE=[font_size=3 font_weight=bold bordercolor=black] CENTER; 
			LINE 'Grocery';
	ENDCOMP;
RUN;
ODS tagsets.ExcelXP CLOSE;
